==> pocl_0.10.orig.tar.gz: pocl-0.10/lib/CL/devices/dev_image.h <==
/* dev_image.h - image data structure used by device implementations

   Copyright (c) 2013 Ville Korhonen
   
   Permission is hereby granted, free of charge, to any person obtaining a copy
   of this software and associated documentation files (the "Software"), to deal
   in the Software without restriction, including without limitation the rights
   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
   copies of the Software, and to permit persons to whom the Software is
   furnished to do so, subject to the following conditions:
   
   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.
   
   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
*/

#ifndef __X86_IMAGE_H__
#define __X86_IMAGE_H__

//Definition of the image datatype used on basic and pthread (and probably tce?)

typedef cl_int dev_sampler_t;

typedef struct dev_image_t {
  void* data;
  cl_int width;
  cl_int height;
  cl_int depth;
  cl_int image_array_size;
  cl_int row_pitch;
  cl_int slice_pitch;
  cl_int num_mip_levels; /* maybe not needed */
  cl_int num_samples; /* maybe not needed */
  cl_int order;
  cl_int data_type;
  cl_int num_channels;
  cl_int elem_size;
} dev_image_t;

#endif

==> pocl_1.1.orig.tar.gz: pocl-1.1/lib/CL/devices/dev_image.h <==
/* dev_image.h - image data structure used by device implementations

   Copyright (c) 2013 Ville Korhonen
   
   Permission is hereby granted, free of charge, to any person obtaining a copy
   of this software and associated documentation files (the "Software"), to deal
   in the Software without restriction, including without limitation the rights
   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
   copies of the Software, and to permit persons to whom the Software is
   furnished to do so, subject to the following conditions:
   
   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.
   
   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
*/

#ifndef __X86_IMAGE_H__
#define __X86_IMAGE_H__

#include "pocl_cl.h"

//Definition of the image and sampler datatype used on basic and pthread (and probably tce?)
typedef cl_int dev_sampler_t;

typedef struct dev_image_t {
  void* data;
  cl_int width;
  cl_int height;
  cl_int depth;
  cl_int image_array_size;
  cl_int row_pitch;
  cl_int slice_pitch;
  cl_int num_mip_levels; /* maybe not needed */
  cl_int num_samples; /* maybe not needed */
  cl_int order;
  cl_int data_type;
  cl_int num_channels;
  cl_int elem_size;
} dev_image_t;

#endif
